@@ -20,6 +20,7 @@ import threading
 import time
 
 from TDhelper.network.http.http_helper import m_http
+from TDhelper.network.http.http_postdataformat import xWwwFormUrlencoded, jsonData, formData
 from TDhelper.Event.Event import Event
 from TDhelper.Spider.models.spider_event import event
 from TDhelper.Spider.models.status import STATUS as SPIDER_STATUS
@@ -36,15 +37,17 @@ class Analysis(Event):
         self.__is_to_fingerprint = True  # 验证页面内容重复临时开关.
         self.__fingerprint = None  # 临时缓存内容hash值
         self.debug = False  # 调试模式开关
-        self.__interceptToken= dict() # 拦截开关
+        self.__interceptToken = dict()  # 拦截开关
         # 定义私有变量
-        self.__access_delays= 0 #控制爬取频率 默认0秒
+        self.__access_delays = 0  # 控制爬取频率 默认0秒
         self.__define_var = dict()  # 变量缓存
         self.__config = dict()  # 爬取规则配置
         self.__configKey = ''  # 规则KEY
+        self.__head = None  # requets head头
+        self.__postdata = None  # request post data
         self.__prefix_domain = None  # 前缀名称
         self.__currentUrl = None  # 当前爬取地址
-        self.__baseCurrentUrl= None # 原始爬取地址
+        self.__baseCurrentUrl = None  # 原始爬取地址
         self.__nextUrl = None  # 生成翻页地址
         self.__state = SPIDER_STATUS.SPIDER_SUCCESS  # 爬虫状态
         self.__response_html = None  # 爬取到的内容
@@ -73,15 +76,17 @@ class Analysis(Event):
     def getFingerprint(self):
         return self.__fingerprint
 
-    def start(self, key, url=None):
+    def start(self, key, url=None, head=None, postdata=None):
         '''
         入口
         '''
         self.__configKey = key
         self.__currentUrl = url
         self.__url_check()
+        self.__head = head
+        self.__postdata = None
         if self.__state == SPIDER_STATUS.SPIDER_SUCCESS:
-            self.__baseCurrentUrl= self.__currentUrl
+            self.__baseCurrentUrl = self.__currentUrl
             self.__httpControl()
             if self.__state == SPIDER_STATUS.HTTP_SUCCESS:
                 # 进入规则路由
@@ -99,16 +104,103 @@ class Analysis(Event):
                 if 'access_delays' in self.__config[self.__configKey]:
                     self.__access_delays = self.__config[self.__configKey]['access_delays']
                 self.__route()
-            if self.__access_delays>0:
+            if self.__access_delays > 0:
                 # 控制访问频率延时.
                 time.sleep(self.__access_delays)
 
+    def search(self, params:[]= []):
+        if params:       
+            for key,config in self.__config.items():
+                self.__configKey= key
+                if "search_cfg" in config:
+                    m_url=''
+                    m_params= {}
+                    m_headers= None
+                    m_metod= 'get'
+                    if "url" in config["search_cfg"]:
+                        m_url = config["search_cfg"]["url"]
+                        if m_url:
+                            self.__currentUrl= m_url
+                    else:
+                        self.__error('confing {0} -root.search_cfg.url, not found key.'.format(key),SPIDER_STATUS.SPIDER_CONFIG_CAN_NOT_FOUND_KEY)
+                    if "params" in config["search_cfg"]:
+                        m_params= config["search_cfg"]["params"]
+                        offset=0
+                        for k,v in config["search_cfg"]["params"].items():
+                            if not v:
+                                if offset < len(params):
+                                    m_params[k]=params[offset]
+                                    offset+=1
+                                else:
+                                    raise Exception('Parameter:array length exceeded.')
+                    else:
+                        self.__error('confing {0} -root.search_cfg.params, not found key.'.format(key),SPIDER_STATUS.SPIDER_CONFIG_CAN_NOT_FOUND_KEY)
+                    if "method" in config["search_cfg"]:
+                        m_method= config["search_cfg"]["method"]
+                    else:
+                        self.__error('confing {0} -root.search_cfg.method, not found key.'.format(key),SPIDER_STATUS.SPIDER_CONFIG_CAN_NOT_FOUND_KEY)
+                    if m_method.lower()=="post":
+                        '''POST,处理POST参数.'''
+                        if "content_type" in config["search_cfg"]:
+                            m_content_type= config["search_cfg"]["content_type"].lower()
+                            if m_content_type == "multipart/form-data":
+                                m_headers, m_post_data= formData(m_params)
+                            elif m_content_type == "application/json":
+                                m_headers, m_post_data= jsonData(m_params)
+                            elif m_content_type == "application/x-www-form-urlencoded":
+                                m_headers, m_post_data= xWwwFormUrlencoded(m_params)
+                            else:
+                                m_headers, m_post_data= xWwwFormUrlencoded(m_params)
+                        else:
+                            self.__error('confing {0} -root.search_cfg.search, not found key.'.format(key),SPIDER_STATUS.SPIDER_CONFIG_CAN_NOT_FOUND_KEY)    
+                    else:
+                        m_headers, m_post_data= xWwwFormUrlencoded(m_params)
+                        if m_post_data:
+                            if self.__currentUrl.find("?",0,len(self.__currentUrl)) < 0:
+                                self.__currentUrl+="?"+str(m_post_data, encoding= 'utf-8')
+                            else:
+                                self.__currentUrl+="&"+str(m_post_data, encoding= 'utf-8')
+                            m_post_data= None
+                    # 开始爬取                        
+                    self.__baseCurrentUrl = self.__currentUrl
+                    self.__url_check()
+                    if m_headers:
+                        self.__head= m_headers
+                    if m_post_data:
+                        self.__postdata= m_post_data
+                    self.__httpControl(method= m_method)
+                    if self.__state == SPIDER_STATUS.HTTP_SUCCESS:
+                        # 进入规则路由
+                        self.__state = SPIDER_STATUS.SPIDER_SUCCESS
+                        if 'name' in self.__config[self.__configKey]:
+                            self.__data['sources'] = self.__config[self.__configKey]['name']
+                        if 'source_index' in self.__config[self.__configKey]:
+                            self.__data['source_index'] = self.__config[self.__configKey]['source_index']
+                        if 'key' in self.__config[self.__configKey]:
+                            self.__data['analysis_key'] = self.__config[self.__configKey]['key']
+                        if 'debug' in self.__config[self.__configKey]:
+                            self.debug = self.__config[self.__configKey]['debug']
+                        if 'reconnect' in self.__config[self.__configKey]:
+                            self.__max_reconnect = self.__config[self.__configKey]['reconnect']
+                        if 'access_delays' in self.__config[self.__configKey]:
+                            self.__access_delays = self.__config[self.__configKey]['access_delays']
+                        self.__route()
+                    if self.__access_delays > 0:
+                        # 控制访问频率延时.
+                        time.sleep(self.__access_delays)
+                else:
+                    return self.__error("-root.search_cfg, can't found key.", SPIDER_STATUS.SPIDER_CONFIG_CAN_NOT_FOUND_KEY)
+        else:
+            raise Exception('parameter is none.')
+
     def __url_check(self):
         self.__state = SPIDER_STATUS.SPIDER_SUCCESS
         self.__define_var = dict()
         self.__data['type'] = None
         self.__data['data'] = None
         self.__data['html'] = ''
+        self.__postdata = None
+        self.__head = None
         if self.__currentUrl == None:
             if self.__state != SPIDER_STATUS.SPIDER_CONFIG_IS_NOT_LOAD:
                 if "entrance" in self.__config[self.__configKey]:
@@ -130,14 +222,14 @@ class Analysis(Event):
             msg = "-root.prefix_domain, can't found key."
             return self.__error(msg, SPIDER_STATUS.SPIDER_CONFIG_CAN_NOT_FOUND_KEY)
         self.__prefix_domain = self.__config[self.__configKey]['prefix_domain']
-        if not re.match(r'^(http|https)://', self.__currentUrl, re.M| re.I):
-            #if re.match(self.__prefix_domain, self.__currentUrl, re.M | re.I) == None:
+        if not re.match(r'^(http|https)://', self.__currentUrl, re.M | re.I):
+            # if re.match(self.__prefix_domain, self.__currentUrl, re.M | re.I) == None:
             self.__currentUrl = self.__prefix_domain + self.__currentUrl
         if 'exclude' in self.__config[self.__configKey]:
             # 检查URL是否需要跳过
             for item in self.__config[self.__configKey]['exclude']:
-                if re.search(item,self.__currentUrl,re.I|re.M):
-                    self.__state= SPIDER_STATUS.SPIDER_EXCLUDE
+                if re.search(item, self.__currentUrl, re.I | re.M):
+                    self.__state = SPIDER_STATUS.SPIDER_EXCLUDE
                     break
 
     def config(self, rulesConfig):
@@ -169,7 +261,7 @@ class Analysis(Event):
         else:
             raise Exception('rules config is null.')
 
-    def __httpControl(self, time_out=5):
+    def __httpControl(self, time_out=5, method= 'GET'):
         '''
         HTTP控件
 
@@ -185,7 +277,10 @@ class Analysis(Event):
             if self.__currentUrl:
                 try:
                     self.__validateInterceptUrl()
-                    html, state = self.__http.getcontent(self.__currentUrl)
+                    if method.upper()=="GET":
+                        html, state = self.__http.getcontent(self.__currentUrl)
+                    else:
+                        html, state= self.__http.post(url=self.__currentUrl,header=self.__head,data=self.__postdata)
                     if state == 200:
                         self.__state = SPIDER_STATUS.HTTP_SUCCESS
                         self.__response_html = html
@@ -195,8 +290,10 @@ class Analysis(Event):
                         for i in range(0, self.__max_reconnect):
                             reconnect_total += 1
                             # TIMEOUT重试
-                            html, state = self.__http.getcontent(
-                                self.__currentUrl)
+                            if method.upper()=="GET":
+                                html, state = self.__http.getcontent(self.__currentUrl)
+                            else:
+                                html, state= self.__http.post(url=self.__currentUrl,header=self.__head,data=self.__postdata)
                             if state == 200:
                                 self.__state = SPIDER_STATUS.HTTP_SUCCESS
                                 self.__response_html = html
@@ -217,29 +314,37 @@ class Analysis(Event):
 
     def __validateInterceptUrl(self):
         if self.__configKey in self.__interceptToken:
-            if not re.search(r"&FbmNv=[a-z|0-9|A-Z]{16}|\?FbmNv=[a-z|0-9|A-Z]{16}", self.__currentUrl, re.I| re.M):
-                if re.search(r"\?", self.__currentUrl, re.I|re.M):
-                    self.__currentUrl=self.__currentUrl+"&FbmNv={0}".format(self.__interceptToken[self.__configKey])
+            if not re.search(r"&FbmNv=[a-z|0-9|A-Z]{16}|\?FbmNv=[a-z|0-9|A-Z]{16}", self.__currentUrl, re.I | re.M):
+                if re.search(r"\?", self.__currentUrl, re.I | re.M):
+                    self.__currentUrl = self.__currentUrl + \
+                        "&FbmNv={0}".format(
+                            self.__interceptToken[self.__configKey])
                 else:
-                    self.__currentUrl=self.__currentUrl+"?FbmNv={0}".format(self.__interceptToken[self.__configKey])
+                    self.__currentUrl = self.__currentUrl + \
+                        "?FbmNv={0}".format(
+                            self.__interceptToken[self.__configKey])
             else:
-                m_ret= re.search(r"[a-z|0-9|A-Z]{16}",self.__currentUrl,re.I|re.M)
+                m_ret = re.search(
+                    r"[a-z|0-9|A-Z]{16}", self.__currentUrl, re.I | re.M)
                 if m_ret:
-                    m_ret= m_ret.group()
+                    m_ret = m_ret.group()
                     if m_ret != self.__interceptToken[self.__configKey]:
-                        self.__currentUrl= re.sub(r'FbmNv=[a-z|0-9|A-Z]{16}',"FbmNv={0}".format(self.__interceptToken[self.__configKey]), self.__currentUrl, count=0, flags=0)
+                        self.__currentUrl = re.sub(r'FbmNv=[a-z|0-9|A-Z]{16}', "FbmNv={0}".format(
+                            self.__interceptToken[self.__configKey]), self.__currentUrl, count=0, flags=0)
 
     def __validateIntercept(self):
         '''
             解决广东电信不良信息ISP拦截跳转问题.
         '''
-        if re.search(r"<title>页面已拦截</title>", self.__response_html, re.I| re.M):
+        if re.search(r"<title>页面已拦截</title>", self.__response_html, re.I | re.M):
             self.__state = SPIDER_STATUS.HTTP_BAD_REQUEST
-            m_token= re.search(r"var token = \"[a-z|0-9|A-Z]{16}\"", self.__response_html, re.I|re.M)
+            m_token = re.search(
+                r"var token = \"[a-z|0-9|A-Z]{16}\"", self.__response_html, re.I | re.M)
             if m_token:
-                m_token=m_token.group()
-                m_token= re.search(r"[a-z|0-9|A-Z]{16}", m_token, re.I|re.M).group()
-                self.__interceptToken[self.__configKey]=m_token
+                m_token = m_token.group()
+                m_token = re.search(
+                    r"[a-z|0-9|A-Z]{16}", m_token, re.I | re.M).group()
+                self.__interceptToken[self.__configKey] = m_token
                 self.__httpControl()
             else:
                 pass
@@ -306,15 +411,18 @@ class Analysis(Event):
             rule_total = 0
             for item in self.__config[self.__configKey]['rules']:
                 if "url_checking" in self.__config[self.__configKey]['rules'][rule_total]:
-                    m_completion="" # 如果地址被拦截则补全参数
-                    m_ret= re.search("&FbmNv=[a-z|0-9|A-Z]{16}|\\?FbmNv=[a-z|0-9|A-Z]{16}", self.__currentUrl,re.I|re.M)
+                    m_completion = ""  # 如果地址被拦截则补全参数
+                    m_ret = re.search(
+                        "&FbmNv=[a-z|0-9|A-Z]{16}|\\?FbmNv=[a-z|0-9|A-Z]{16}", self.__currentUrl, re.I | re.M)
                     if m_ret:
-                        m_completion= m_ret.group()
-                        if re.search(r"^\?",m_completion,re.I|re.M):
-                            m_completion= "\\"+ m_completion
-                        m_validateUrl="("+self.__config[self.__configKey]['rules'][rule_total]['url_checking']+")"+m_completion
+                        m_completion = m_ret.group()
+                        if re.search(r"^\?", m_completion, re.I | re.M):
+                            m_completion = "\\" + m_completion
+                        m_validateUrl = "(" + \
+                            self.__config[self.__configKey]['rules'][rule_total]['url_checking'] + \
+                            ")"+m_completion
                     else:
-                        m_validateUrl=self.__config[self.__configKey]['rules'][rule_total]['url_checking']
+                        m_validateUrl = self.__config[self.__configKey]['rules'][rule_total]['url_checking']
                     matching_rule = re.fullmatch(
                         m_validateUrl, self.__currentUrl, re.I | re.S)
                     if not matching_rule:
@@ -493,10 +601,13 @@ class Analysis(Event):
                         if ('extract_regex' in m_config['func']) and ('replace_str' in m_config['func']):
                             tmp_body = ''
                             body = m_body.group()
-                            tmp_body = re.sub(m_config['func']['extract_regex'],m_config['func']['replace_str'], body, count=0, flags=0)
+                            tmp_body = re.sub(
+                                m_config['func']['extract_regex'], m_config['func']['replace_str'], body, count=0, flags=0)
                             if 'template' in m_config['func']:
-                                tmp_body= re.sub(r"{{value}}",tmp_body,m_config['func']['template'],count=0, flags=0)
-                            self.__response_html = re.sub(m_config['extract_regex'], tmp_body, self.__response_html, count=0, flags=0)
+                                tmp_body = re.sub(
+                                    r"{{value}}", tmp_body, m_config['func']['template'], count=0, flags=0)
+                            self.__response_html = re.sub(
+                                m_config['extract_regex'], tmp_body, self.__response_html, count=0, flags=0)
                             if 'debug' in m_config:
                                 if m_config['debug']:
                                     self.on(event.onDebug, self, **{"event": 'actiondebug', "data": "-{0}, regular:{1}\r\n\t- befor:{2}\r\n\t- after:{3}".format(
