@@ -21,22 +21,22 @@ class RPC:
         self._current_service= None
 
     def _getApi(self, service, method):
-        if service not in self._apisTable:
+        if service+method not in self._apisTable:
             # 远程获取
             m_heads = {"api-token": self._access_token}
             status, body = GET(uri=self._sc_uri+"rpc/?key="+service +
                                "&method="+method, time_out=15, http_headers=m_heads)
             if status == 200:
-                self._apisTable[service] = json.loads(
+                self._apisTable[service+method] = json.loads(
                     str(body, encoding='utf-8'))
         # 从本地获取API配置
-        if service in self._apisTable:
-            if self._apisTable[service]['state'] == 200:
-                return True, self._apisTable[service]['msg']
+        if service+method in self._apisTable:
+            if self._apisTable[service+method]['state'] == 200:
+                return True, self._apisTable[service+method]['msg']
             else:
-                return False, self._apisTable[service]['msg']
+                return False, self._apisTable[service+method]['msg']
         else:
-            return False, "can't found %s api." % service
+            return False, "can't found %s api." % service+method
 
     def register(self, service: dict, hosts: [], methods: []):
         '''
@@ -465,4 +465,8 @@ if __name__ == '__main__':
             methods=item['methods']))
     '''
     g=m_rpc.handle("REMOTE_CONFIG")
-    print(g.call("REMOTE_CONFIG_SERVICE_CREATE",**{"name":'ggg',"service_key":"cccc"}))
\ No newline at end of file
+    ret= g.call("REMOTE_CONFIG_SERVICE_CREATE",**{"name":'ggg',"service_key":"cccc"})
+    print(ret)
+    m_id= ret['data']['id']
+    ret=g.call('REMOTE_CONFIG_CONFIG_REGISTER',**{"config_key":"test1","config_value":"testvalue","service":m_id})
+    print(ret)
\ No newline at end of file
